#include <Arduino.h>
#include "WiFi.h"
#include "theSecrets.h"

#include "freertos/FreeRTOS.h"
#include "freertos/task.h"
#include "esp_wifi.h"
#include "esp_event.h"
#include "nvs_flash.h"
#include "lwip/err.h"
#include "lwip/sockets.h"
#include "lwip/sys.h"
#include <lwip/netdb.h>

void connectToWifi()
{
  WiFi.begin(ssid, psk);
  while (WiFi.status() != WL_CONNECTED)
  {
    delay(200);
  }
}

void handle_wifi_events(WiFiEvent_t event, WiFiEventInfo_t info)
{
  Serial.print("[WiFi] ");
  switch (event)
  {
  case ARDUINO_EVENT_WIFI_STA_START:
    Serial.printf("Attempting to connect to WPA SSID: %s\n", ssid);
    break;
  case ARDUINO_EVENT_WIFI_STA_CONNECTED:
    Serial.println("connected");
    break;
  case ARDUINO_EVENT_WIFI_STA_DISCONNECTED:
    Serial.println("disconnected");
    break;
  case ARDUINO_EVENT_WIFI_STA_GOT_IP:
    Serial.print("IP address: ");
    Serial.println(WiFi.localIP());
    break;
  default:
    Serial.println(event);
  }
}

void setup_wifi()
{
  WiFi.mode(WIFI_STA);
  WiFi.onEvent(handle_wifi_events, ARDUINO_EVENT_MAX);
  connectToWifi();
}

static void intercept_task(void *pvParameters)
{
  Serial.println("Intercept");
  vTaskDelete(NULL);
}

void setup()
{
  ESP_ERROR_CHECK(nvs_flash_init());
  ESP_ERROR_CHECK(esp_netif_init());
  ESP_ERROR_CHECK(esp_event_loop_create_default());
  Serial.begin(115200);
  setup_wifi();
  xTaskCreate(intercept_task, "intercept", 4096, (void *)AF_INET, 5, NULL);
}

void loop()
{
}